@@ -1,8 +1,9 @@
-from typing import List, Optional
+from typing import List, Optional, Any
 from pydantic import BaseModel
 
 
 class Skill(BaseModel):
+    name: str
     description: str
 
 
@@ -10,18 +11,28 @@ class Provider(BaseModel):
     name: str
     url: str
 
+class Authentication(BaseModel):
+    auth_method: str
+    header: Optional[str]
+    secret: Optional[str]
 
 from typing import ClassVar
 
 class AgentCard(BaseModel):
     TYPE_A2A: ClassVar[str] = 'type_a2a'
-    TYPE_MCP: ClassVar[str] = 'mcp_type'
+    TYPE_MCP: ClassVar[str] = 'type_mcp'
+    TYPE_LLM: ClassVar[str] = 'type_llm'
     url: str
+    id: str
     name: str
+    org_id: Optional[str] = None
+    alias: Optional[str] = None
     type: Optional[str] = None
+    authentication: Optional[Authentication] = None
     tag: Optional[str] = None
     github: Optional[str] = None
     skills: Optional[List[Skill]] = None
+    tools: Optional[List[Any]] = None
     status: Optional[str] = None
     version: Optional[str] = None
     examples: Optional[List[str]] = None
